============
merge-bisect
============

Like git bisect, but only with merge commits.

Some features:

* Pure Python
* No dependencies (other than git installed)
* Single file. Installing is as easy as downloading a ``merge_bisect/__main__.py`` file

Install
+++++++

::

    pipx install merge-bisect
